# Changelog

## 3.0.1
* Change puppetssh provider name to 'ssh' on 1.12+, and deprecate passing
  'puppetssh' when using split Puppet config files

## 3.0.0
* New or changed parameters:
    * Add dhcp_subnets parameter
    * Add dhcp_search_domains parameter (is relayed to dhcp::pool)
    * Add ensure_packages_version parameter for extra packages, can be set to
      'installed', 'present', 'latest' or 'absent'
    * Add libvirt_backend, set to 'virsh' for 1.11 compatibility
    * Add mcollective_user parameter
    * Add puppet_split_config_files parameter, set to false for 1.11
      compatibility
    * Add ssl_disabled_ciphers parameter for usage with 1.12 or later
    * Add tftp_managed parameter. If set to false, theforeman-tftp is not used
    * Rename virsh_network to libvirt_network
    * Remove autosign_location parameter, note that `#{puppetdir}/autosign.conf`
      is used in the proxy code itself for the path.
    * Remove puppet_cache_location parameter, no longer used by the smart proxy
    * Remove deprecated parameters for 1.10 and older
* New or changed parameters on smart proxy plugin classes:
    * Add contentdir, reportsdir, failed_dir and configure_openscap_repo to
      openscap class
* Other changes and fixes:
    * Use foreman::providers to install foreman_smartproxy dependencies
    * Pass ssl_ca to foreman_smartproxy for rest_v3 provider compatibility
    * Change default log level to INFO
    * Copy mboot.c32 for TFTP proxies
    * Fix ordering of Puppet server installation before proxy user (#14942)
* Compatibility warnings:
    * Removed support for Smart Proxy 1.10 and older, 1.11+ is required
    * Change puppetrun and puppetrun_listen_on parameters to puppet and
      puppet_listen_on respectively
    * 1.11 users must set `puppet_split_config_files => false` with Puppet

## 2.5.0
* New or changed parameters:
    * Add dhcp_split_config_files parameter, set to false for 1.10 or prior
      compatibility
    * Add dhcp_provider parameter to replace dhcp_vendor (deprecated)
    * Add logs, logs_listen_on parameters to manage new logs smart proxy module
    * Add log_buffer, log_buffer_errors parameters
    * Add tftp_manage_wget parameter to disable wget installation
* New classes to install smart proxy plugins:
    * foreman_proxy::plugin::discovery to install Discovery support
* New or changed parameters on smart proxy plugin classes:
    * Warning: removed ssh_user parameter from remote_execution plugin, the user
      is controlled from the Foreman plugin
    * Add local_working_dir, remote_working_dir parameters to remote_execution
      plugin
    * Add version parameter to openscap plugin
    * Add pulp_dir, pulp_content_dir, mongodb_dir parameters to pulp plugin
    * Add database_path, console_auth parameters to dynflow plugin
* Other changes and fixes:
    * Support Puppet 3.0 minimum
    * Support Fedora 21, remove Debian 6 (Squeeze), add Ubuntu 16.04
    * Create TFTP directories for ZTP and POAP files (#13024)
    * Use lower case FQDN to access Puppet SSL certificates (#8389)
    * Fix Puppet SSL directory under Puppet 4
    * Fix proxy registration URL take current ssl_port parameter value
    * Fix kafo data type on generate_keys parameter (#12988)
    * Refresh log/log_level parameter documentation

## 2.4.2
* Fix path to dhcpd.conf on FreeBSD

## 2.4.1
* Fix DNS providers under 1.10 to have "dns_" prefix (#12157)
* Fix missing kafo data type on powerdns::manage_database parameter
* Test speed improvements

## 2.4.0
* New or changed parameters:
    * Add dns_split_config_files parameter, set to false for 1.9 or prior
      compatibility
    * Add dhcp_server parameter for address of the DHCP server (1.10+)
* Other changes and fixes:
    * Support and test module under Puppet 4
    * Support version 1.10 with split DNS configuration files
    * Add FreeBSD support
    * Add foreman_proxy::plugin::remote_execution::ssh and
      foreman_proxy::plugin::dynflow plugin classes
    * Add foreman_proxy::plugin::dns::powerdns plugin class
    * Pass dhcp_key_name and secret to DHCP module OMAPI parameters
    * Replace random_password/cache_data from theforeman/foreman with
      puppet/extlib

## 2.3.0
* New or changed parameters:
    * Add puppet\_use\_cache/puppet\_cache\_location parameters to control
      caching functions of the 'puppet' module
    * Add new api\_* parameters to foreman_proxy::plugin::salt for its access
      to the Salt API (#8473)
    * Add bind\_host parameter for smart proxy bind IP/host in 1.8+
    * Add salt\_puppetrun\_cmd parameter to change Salt command used for
      Puppet runs in 1.8+
    * Add dhcp\_omapi\_port parameter to control the OMAPI port used for ISC
      dhcpd management in 1.9+
* Other changes and fixes:
    * Mark support for new theforeman releases using puppetlabs/concat

## 2.2.3
* Don't configure dns_key if nsupdate_gss is used (#10436)
* Copy libutil.c32 PXELinux 6 file on Debian 8/Jessie (#10255)

## 2.2.2
* Copy ldlinux.c32 PXELinux 6 file on Debian 8/Jessie (#10255)
* Change tftp_servername parameter default to undef (#9896)

## 2.2.1
* Fix template variable lookups under the future parser
* Replace private() for future parser compatibility

## 2.2.0
* New classes to install smart proxy plugins:
    * foreman_proxy::plugin::abrt to install ABRT support
    * foreman_proxy::plugin::chef to install Chef support
    * foreman_proxy::plugin::openscap to install OpenSCAP support
    * foreman_proxy::plugin::salt for Salt management support
* New or changed parameters:
    * Add http_port/ssl_port parameters to listen on both HTTP/HTTPS
      simultaneously, deprecates port parameter (#8990)
    * Add *\_listen\_on parameters to control which modules listen on HTTP and
      HTTPS ports (#8990)
    * Add dhcp_option_domain parameter to change or disable setting dhcpd
      domain name option
    * Add foreman_ssl* parameters to specify keys used to access Foreman API
      from smart proxy plugins
    * Add log_level parameter to control smart proxy logging
    * Add plugin_version parameter to change default plugin package ensure
      value, add version parameter to each plugin class
* Other features:
    * Configure templates module for reverse proxying provisioning template
      requests
    * Set :foreman_url for Foreman API location
    * Support PXELinux/TFTP installation on Debian 8 (Jessie)
    * Manage pulpnode configuration in foreman_proxy::plugin::pulp
* Other changes and fixes:
    * Only manage sudo rules if puppetca or puppetrun are enabled
    * Use puppetrun_user parameter in sudo rules
    * Override TFTP server root from tftp_root parameter
    * Improvements for Puppet 4 and future parser support
    * Fix compatibility with theforeman/dns 2.0.0
    * Fix compatibility with theforeman/puppet 3.0.0
    * Fix dependency on LSB facts (#9449)
    * Fix third party package resources to use ensure_packages
    * Fix metadata quality issues, pinning dependencies

## 2.1.0
* Add puppetssh_wait parameter (#7860)
* Fix error referencing class that may not have been evaluted

## 2.0.2
* Set trusted_hosts default value to FQDN

## 2.0.1
* Validate IP address facts used in DHCP/DNS templates (#7263)
* Fix relationship specification for early Puppet 2.7 releases
* Fix lint issue

## 2.0.0
* Deploy configuration files for Foreman 1.6 modular smart proxy
    * Compatible with 1.6 only, use 1.x versions for 1.5 or older
* Add foreman_proxy::plugin define for installation of proxy plugins
* Add foreman_proxy::plugin::pulp class for Pulp plugin
* Ensure foreman_proxy::service is refreshed after SSL certs change
* Install apipie-bindings package for foreman_smartproxy registration
* Add $version parameter to control package version
* Update puppet.yml config file for directory environment settings
* Fix operatingsystemrelease comparison for CentOS 7
* Fix handling of alias/VLAN interface fact names
* Remove mocha test dependency
* Fix lint issues

## 1.6.1
* Fix user shell path so it's valid on Debian (#5390)

## 1.6.0
* Add parameters for all Foreman 1.4 and realm (1.5) features

## 1.5.0
* Add dns_provider parameter
* Use ensure_packages for non-core wget package
* Remove template source from header for Puppet 3.5 compatibility
* Fix missing dependency on foreman module
* Fix top-scope variable without an explicit namespace

## 1.4.0
* Add $puppetrun_provider parameter
* Fix disabling of ssl_* settings when $ssl is false
* Puppet 2.6 support deprecated
* Fix stdlib dependency for librarian-puppet
